@@ -3,14 +3,14 @@
 from mcipc.query import Client as QueryClient
 from mcipc.rcon import Client as RCONClient
 from mcipc.rcon import InvalidPacketStructure
-from mcipc.rcon import InvalidStructure
+from mcipc.rcon import StructureNotFound
 from mcipc.rcon import WrongPassword
 from mcipc.rcon import rconcmd
 
 
 __all__ = [
     'InvalidPacketStructure',
-    'InvalidStructure',
+    'StructureNotFound',
     'WrongPassword',
     'rconcmd',
     'QueryClient',
