@@ -3,13 +3,13 @@
 from mcipc.rcon.client import Client
 from mcipc.rcon.console import rconcmd
 from mcipc.rcon.exceptions import InvalidPacketStructure
-from mcipc.rcon.exceptions import InvalidStructure
+from mcipc.rcon.exceptions import StructureNotFound
 from mcipc.rcon.exceptions import WrongPassword
 
 
 __all__ = [
     'InvalidPacketStructure',
-    'InvalidStructure',
+    'StructureNotFound',
     'WrongPassword',
     'rconcmd',
     'Client'
