@@ -6,4 +6,4 @@ from mcipc.rcon.datastructures.players import Players
 from mcipc.rcon.datastructures.seed import Seed
 
 
-__all__ = ['Location', 'Players', 'Seed']
+__all__ = ['Help', 'Location', 'Players', 'Seed']
