@@ -1,5 +1,6 @@
 """More complex data structures."""
 
+from __future__ import annotations
 from json import dumps, loads
 from logging import getLogger
 from typing import Callable, NamedTuple
@@ -23,7 +24,7 @@ class Handshake(NamedTuple):
     next_state: State
 
     @classmethod
-    def read(cls, readfunc: Callable):
+    def read(cls, readfunc: Callable) -> Handshake:
         """Creates a handshake object from the respective bytes."""
         size = VarInt.read(readfunc)
         LOGGER.debug('Read size: %s', size)
@@ -59,7 +60,7 @@ class SLPResponse(NamedTuple):
         return payload_size + payload
 
     @classmethod
-    def read(cls, readfunc: Callable):
+    def read(cls, readfunc: Callable) -> SLPResponse:
         """Creates the SLP response from the respective payload."""
         total_size = VarInt.read(readfunc)
         LOGGER.debug('Read total size: %s', total_size)
